/* A Bison parser, made by GNU Bison 3.0.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_CATA_PARSER_CATALOGFILE_TAB_H_INCLUDED
# define YY_CATA_PARSER_CATALOGFILE_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef CATA_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define CATA_DEBUG 1
#  else
#   define CATA_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define CATA_DEBUG 1
# endif /* ! defined YYDEBUG */
#endif  /* ! defined CATA_DEBUG */
#if CATA_DEBUG
extern int cata_debug;
#endif

/* Token type.  */
#ifndef CATA_TOKENTYPE
# define CATA_TOKENTYPE
  enum cata_tokentype
  {
    cataERROR = 258,
    cataTOP = 259,
    cataCATEGORY = 260,
    cataDOCUMENT = 261,
    cataHUMAN = 262,
    cataWITH = 263,
    cataARCHIVE = 264,
    cataEQUAL = 265,
    cataCOLON = 266,
    cataCOMMA = 267,
    cataHASH = 268,
    cataNUMBER = 269,
    cataSTRING = 270
  };
#endif
/* Tokens.  */
#define cataERROR 258
#define cataTOP 259
#define cataCATEGORY 260
#define cataDOCUMENT 261
#define cataHUMAN 262
#define cataWITH 263
#define cataARCHIVE 264
#define cataEQUAL 265
#define cataCOLON 266
#define cataCOMMA 267
#define cataHASH 268
#define cataNUMBER 269
#define cataSTRING 270

/* Value type.  */
#if ! defined CATA_STYPE && ! defined CATA_STYPE_IS_DECLARED
typedef union CATA_STYPE CATA_STYPE;
union CATA_STYPE
{
#line 61 "parser/catalogFile.y" /* yacc.c:1909  */

  off_t  size;
  char   string[MAX_SIZE_STRING+1];
  char   hash[MAX_SIZE_MD5+1];
  Category* category;
  Human*    human;
  Document* document;
  Archive*  archive;

#line 102 "parser/catalogFile.tab.h" /* yacc.c:1909  */
};
# define CATA_STYPE_IS_TRIVIAL 1
# define CATA_STYPE_IS_DECLARED 1
#endif



int cata_parse (yyscan_t yyscanner, Collection* coll, Category* category, Human* human, Document* document, Archive* archive);
/* "%code provides" blocks.  */
#line 27 "parser/catalogFile.y" /* yacc.c:1909  */

/*=======================================================================
 * Version: this file is generated by BISON using catalogFile.y
 * Project: MediaTeX
 * Module : catalogFile parser
 *
 * catalog file parser

 MediaTex is an Electronic Records Management System
 Copyright (C) 2014 2015 Nicolas Roche
   
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 any later version.
   
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
   
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/

#define YYSTYPE CATA_STYPE

#line 140 "parser/catalogFile.tab.h" /* yacc.c:1909  */

#endif /* !YY_CATA_PARSER_CATALOGFILE_TAB_H_INCLUDED  */
